#
# spec file for package fs-uae-launcher
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fs-uae-launcher
Version:        3.1.68
Release:        1.6
Summary:        Graphical configuration frontend and launcher for FS-UAE
License:        GPL-2.0-or-later
Group:          System/Emulators/Other
URL:            https://fs-uae.net/
Source:         https://fs-uae.net/files/FS-UAE-Launcher/Stable/%{version}/fs-uae-launcher-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       fs-uae
Requires:       python3-opengl
Requires:       python3-qt5
Requires:       python3-requests
Recommends:     python3-lhafile
BuildArch:      noarch

%description
FS-UAE Launcher is a graphical configuration program and launcher for FS-UAE.

%prep
%setup -q

%build
python3 setup.py build
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} prefix=%{_prefix}
%suse_update_desktop_file -r %{name} System Emulator
rm -rf %{buildroot}/%{_datadir}/doc
%fdupes %{buildroot}%{_datadir}
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.68:
  * Fixes for PyQt5 errors observed on Fedora 35.
* Fri Jan 21 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.66
  * Added some docs from master branch
  * Updated controllers
- from version 3.1.64
  * Removed unwanted stuff from PyQt5
  * Remove libfontconfig and libfreetype
- Rename Source0 field to Source
- Update URL in Source field
* Mon Nov 22 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.63
  * Removed cacert.pem (should be handled by certifi package now).
  * Launcher settings plugins page did not respect new FS-UAE/System directory.
  * Remove empty "Directories" settings page.
  * Fix disappearing configs when base_dir is specified with a trailing slash.
  * Prefer $HOME/FS-UAE if it exists, otherwise use $DOCUMENTS/FS-UAE.
  * Added lots of game controller configs.
  * Support ~/ when  overriding base_dir in config file + create dir if needed.
  * Fix layout issues caused by floats not being acceptedby pyqt5 any more.
  * Fix loading WHDLoad .lha archives on Windows.
  * Some changes to how/where plugins are found.
  * Build system update.
  * Official builds created with pyinstaller.
  * Better support for High-DPI displays in Windows.
* Thu Nov 11 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.42
  * Remove embedded copy of PyOpenGL
- Add python3-opengl to Requires
- Switch source tarball format to xz
* Sat Apr 25 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.5
  * No changes, version bump only to sync with fs-uae and -arcade
* Thu Apr 23 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.4
  * No changes, version bump only to sync with fs-uae and -arcade
* Tue Mar 10 2020 Martin Hauke <mardnh@gmx.de>
- Fixed crash when starting the Launcher in a KDE environment
* Wed Nov  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.2
  * Another fix for global WHDLoad quit key.
  * Fixed a misleading warning when cyberstorm ROM was not found
- Update to version 3.0.1
  * Scanner bug prevented Conquests of the Longbow WHDLoad to be
    recognized.
  * The correct kickstart wasn’t always loaded.
  * Cloanto ROMs were not always decrypted.
  * Fix for global WHDLoad quit key.
* Wed Jul  3 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to version 3.0.0
  * Plugins can provide files for offline use (WHDLoad, JST, SKick,
    etc)
  * Added support for .gz/.adz/.roz/.xz-compressed files
  * Support WHDLoad versions 18.4 and 18.5 (game database)
  * Revert fullscreen_mode to default when upgrading from older
    versions
  * Use https for all more fs-uae.net and openretro.org
    communication
  * Support hd_requirements = xpkmaster.library
  * Fixed problem on Windows where devices were sometimes not
    detected
  * Make configurations list wider when window width is quite large
  * Try to use config from game database when launching with a
    WHDLoad archive.
  * Extract WHDLoad arguments from .info file when loading a
    WHDLoad archive
  * Sync "unpublished" games from the online game database, option
    to show
  * Many bugfixes and smaller improvements (see Changelog for
    details)
- Add python3-requests requirement, needed for the new version to
  start
- Recommend python3-lhafile for .lha file support
- Remove obsolete %%post/%%postun sections for no longer supported
  distributions
* Wed Aug  8 2018 mardnh@gmx.de
- Initial package, version 2.8.3
  based on home:FrodeSolheim:stable/fs-uae-launcher
